@@ -3,14 +3,17 @@
 
 import inkex
 
+
 class RgbBarrel(inkex.ColorExtension):
     """
     Cycle colors RGB -> BRG
 
     aka  Do a Barrel Roll!
     """
+
     def modify_color(self, name, color):
         return inkex.Color((color.blue, color.red, color.green))
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     RgbBarrel().run()
